#ifndef _ELM_PANEL_INTERNAL_PART_EO_H_
#define _ELM_PANEL_INTERNAL_PART_EO_H_

#ifndef _ELM_PANEL_INTERNAL_PART_EO_CLASS_TYPE
#define _ELM_PANEL_INTERNAL_PART_EO_CLASS_TYPE

typedef Eo Elm_Panel_Internal_Part;

#endif

#ifndef _ELM_PANEL_INTERNAL_PART_EO_TYPES
#define _ELM_PANEL_INTERNAL_PART_EO_TYPES


#endif
/** Elementary panel internal part class
 *
 * @ingroup Elm_Panel_Internal_Part
 */
#define ELM_PANEL_INTERNAL_PART_CLASS elm_panel_internal_part_class_get()

EWAPI const Efl_Class *elm_panel_internal_part_class_get(void);

#endif
